# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: start_bullettime.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16start_bullettime.proto\x12\x11insta360.messages"\x11\n\x0fStartBulletTime"\x15\n\x13StartBulletTimeRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "start_bullettime_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_STARTBULLETTIME"]._serialized_start = 45
    _globals["_STARTBULLETTIME"]._serialized_end = 62
    _globals["_STARTBULLETTIMERESP"]._serialized_start = 64
    _globals["_STARTBULLETTIMERESP"]._serialized_end = 85
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_flowstate_enable.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1aget_flowstate_enable.proto\x12\x11insta360.messages"\x14\n\x12GetFlowstateEnable"(\n\x16GetFlowstateEnableResp\x12\x0e\n\x06\x65nable\x18\x01 \x01(\rB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_flowstate_enable_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETFLOWSTATEENABLE"]._serialized_start = 49
    _globals["_GETFLOWSTATEENABLE"]._serialized_end = 69
    _globals["_GETFLOWSTATEENABLERESP"]._serialized_start = 71
    _globals["_GETFLOWSTATEENABLERESP"]._serialized_end = 111
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bt_central_notification.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bluetooth_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1d\x62t_central_notification.proto\x12\x11insta360.messages\x1a\x0f\x62luetooth.proto"X\n NotificatoinDiscoverBTPeripheral\x12\x34\n\x0bperipherals\x18\x01 \x03(\x0b\x32\x1f.insta360.messages.BTPeripheral"X\n!NotificatoinConnectedToPeripheral\x12\x33\n\nperipheral\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.BTPeripheral"Y\n"NotificatoinDisconnectedPeripheral\x12\x33\n\nperipheral\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.BTPeripheralB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "bt_central_notification_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATOINDISCOVERBTPERIPHERAL"]._serialized_start = 69
    _globals["_NOTIFICATOINDISCOVERBTPERIPHERAL"]._serialized_end = 157
    _globals["_NOTIFICATOINCONNECTEDTOPERIPHERAL"]._serialized_start = 159
    _globals["_NOTIFICATOINCONNECTEDTOPERIPHERAL"]._serialized_end = 247
    _globals["_NOTIFICATOINDISCONNECTEDPERIPHERAL"]._serialized_start = 249
    _globals["_NOTIFICATOINDISCONNECTEDPERIPHERAL"]._serialized_end = 338
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: editinfo_list.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x65\x64itinfo_list.proto\x12\x11insta360.messages"F\n\x0c\x46\x61voriteInfo\x12\x1c\n\x14playback_is_favorite\x18\x01 \x01(\x08\x12\x18\n\x10modify_timestamp\x18\x02 \x01(\x03"Y\n\x0c\x45\x64itFileInfo\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x36\n\rfavorite_info\x18\x02 \x01(\x0b\x32\x1f.insta360.messages.FavoriteInfo"P\n\x10\x45\x64itFileInfoList\x12<\n\x13\x65\x64it_file_info_list\x18\x01 \x03(\x0b\x32\x1f.insta360.messages.EditFileInfoB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "editinfo_list_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_FAVORITEINFO"]._serialized_start = 42
    _globals["_FAVORITEINFO"]._serialized_end = 112
    _globals["_EDITFILEINFO"]._serialized_start = 114
    _globals["_EDITFILEINFO"]._serialized_end = 203
    _globals["_EDITFILEINFOLIST"]._serialized_start = 205
    _globals["_EDITFILEINFOLIST"]._serialized_end = 285
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fw_upgrade_state.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x66w_upgrade_state.proto\x12\x11insta360.messages"\xbb\x08\n\x13UpgradeStateOptions\x12\x43\n\x05state\x18\x01 \x01(\x0e\x32\x34.insta360.messages.UpgradeStateOptions.Upgrage_State\x12H\n\nerror_code\x18\x02 \x01(\x0e\x32\x34.insta360.messages.UpgradeStateOptions.Upgrage_State"\x94\x07\n\rUpgrage_State\x12\x16\n\x12UPGRADE_STATE_IDLE\x10\x00\x12\x1c\n\x18UPGRADE_STATE_PRE_NOFILE\x10\x01\x12%\n!UPGRADE_STATE_GET_FILE_LIST_ERROR\x10\x02\x12"\n\x1eUPGRADE_STATE_PRE_CAME_NOPOWER\x10\x03\x12"\n\x1eUPGRADE_STATE_PRE_CASE_NOPOWER\x10\x04\x12\x1c\n\x18UPGRADE_STATE_ING_UNPACK\x10\x05\x12"\n\x1eUPGRADE_STATE_ING_UNPACK_ERROR\x10\x06\x12%\n!UPGRADE_STATE_ING_CHECK_MD5_ERROR\x10\x07\x12#\n\x1fUPGRADE_STATE_ING_CASE_FW_START\x10\x08\x12#\n\x1fUPGRADE_STATE_ING_CASE_FW_ERROR\x10\t\x12&\n"UPGRADE_STATE_ING_CASE_BT_FW_START\x10\n\x12&\n"UPGRADE_STATE_ING_CASE_BT_FW_ERROR\x10\x0b\x12&\n"UPGRADE_STATE_ING_CAME_BT_FW_START\x10\x0c\x12&\n"UPGRADE_STATE_ING_CAME_BT_FW_ERROR\x10\r\x12#\n\x1fUPGRADE_STATE_ING_CAME_FW_START\x10\x0e\x12\'\n#UPGRADE_STATE_VERSION_CHECK_SUCCESS\x10\x0f\x12&\n"UPGRADE_STATE_VERSION_CHECK_FAILED\x10\x10\x12\x1f\n\x1bUPGRADE_STATE_ING_FW_UPLOAD\x10\x11\x12"\n\x1eUPGRADE_STATE_FW_UPLOAD_FAILED\x10\x12\x12#\n\x1fUPGRADE_STATE_FW_UPLOAD_SUCCESS\x10\x13\x12)\n%UPGRADE_STATE_PRE_USB_SHAKEHANDS_FAIL\x10\x14\x12(\n$UPGRADE_STATE_PRE_BT_SHAKEHANDS_FAIL\x10\x15\x12\'\n#UPGRADE_STATE_CAME_AND_CASE_NOPOWER\x10\x16\x12-\n)UPGRADE_STATE_ING_CAME_BT_FW_DOUBLE_START\x10\x17\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "fw_upgrade_state_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_UPGRADESTATEOPTIONS"]._serialized_start = 46
    _globals["_UPGRADESTATEOPTIONS"]._serialized_end = 1129
    _globals["_UPGRADESTATEOPTIONS_UPGRAGE_STATE"]._serialized_start = 213
    _globals["_UPGRADESTATEOPTIONS_UPGRAGE_STATE"]._serialized_end = 1129
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live_stream_params_update.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *
from window_crop_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1flive_stream_params_update.proto\x12\x11insta360.messages\x1a\roptions.proto\x1a\x16window_crop_info.proto"\xb5\x02\n\x16LiveStreamParamsUpdate\x12\x45\n\x11video_encode_type\x18\x01 \x01(\x0e\x32*.insta360.messages.Options.VideoEncodeType\x12\x11\n\tres_width\x18\x02 \x01(\r\x12\x12\n\nres_height\x18\x03 \x01(\r\x12\x0f\n\x07res_fps\x18\x04 \x01(\r\x12\x1d\n\x15\x66lowstate_base_enable\x18\x05 \x01(\x08\x12;\n\x10window_crop_info\x18\x06 \x01(\x0b\x32!.insta360.messages.WindowCropInfo\x12@\n\x15half_window_crop_info\x18\x07 \x01(\x0b\x32!.insta360.messages.WindowCropInfoB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "live_stream_params_update_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_LIVESTREAMPARAMSUPDATE"]._serialized_start = 94
    _globals["_LIVESTREAMPARAMSUPDATE"]._serialized_end = 403
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: error.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0b\x65rror.proto\x12\x11insta360.messages"\xda\x01\n\x05\x45rror\x12\x30\n\x04\x63ode\x18\x01 \x01(\x0e\x32".insta360.messages.Error.ErrorCode\x12\x0f\n\x07message\x18\x02 \x01(\t"\x8d\x01\n\tErrorCode\x12\x11\n\rUNKNOWN_ERROR\x10\x00\x12\x14\n\x10UNKNOWN_MSG_CODE\x10\x01\x12\x17\n\x13UNKNOWN_MSG_PAYLOAD\x10\x02\x12\x11\n\rEXECUTE_ERROR\x10\x03\x12\x1a\n\x16OVER_FILE_NUMBER_LIMIT\x10\x04\x12\x0f\n\x0bSYSTEM_BUSY\x10\x05\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "error_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_ERROR"]._serialized_start = 35
    _globals["_ERROR"]._serialized_end = 253
    _globals["_ERROR_ERRORCODE"]._serialized_start = 112
    _globals["_ERROR_ERRORCODE"]._serialized_end = 253
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0csensor.proto\x12\x11insta360.messages"\xcb\x01\n\x06Sensor\x12\x0f\n\x07serials\x18\x01 \x03(\t\x12,\n\x04type\x18\x02 \x01(\x0e\x32\x1e.insta360.messages.Sensor.Type\x12\n\n\x02id\x18\x03 \x03(\t"v\n\x04Type\x12\x0c\n\x08PANO_577\x10\x00\x12\x0c\n\x08WIDE_577\x10\x01\x12\x0c\n\x08WIDE_283\x10\x02\x12\x0c\n\x08WIDE_586\x10\x03\x12\n\n\x06\x41\x46_586\x10\x04\x12\x0c\n\x08PANO_283\x10\x05\x12\x0c\n\x08PANO_586\x10\x06\x12\x0e\n\nACTION_577\x10\x07*q\n\x0cSensorDevice\x12\x19\n\x15SENSOR_DEVICE_UNKNOWN\x10\x00\x12\x17\n\x13SENSOR_DEVICE_FRONT\x10\x01\x12\x16\n\x12SENSOR_DEVICE_REAR\x10\x02\x12\x15\n\x11SENSOR_DEVICE_ALL\x10\x03*\xb8\x02\n\x07\x46ovType\x12\x0c\n\x08\x46OV_WIDE\x10\x00\x12\x0e\n\nFOV_LINEAR\x10\x01\x12\x11\n\rFOV_ULTRAWIDE\x10\x02\x12\x0e\n\nFOV_NARROW\x10\x03\x12\x0b\n\x07\x46OV_POV\x10\x04\x12\x13\n\x0f\x46OV_LINEAR_PLUS\x10\x05\x12\x18\n\x14\x46OV_LINEAR_45HORIZON\x10\x06\x12\x10\n\x0c\x46OV_TYPE_FPV\x10\x07\x12\x12\n\x0e\x46OV_TYPE_SUPER\x10\x08\x12\x17\n\x13\x46OV_TYPE_TINYPLANET\x10\t\x12\x19\n\x15\x46OV_TYPE_INFINITYWIDE\x10\n\x12\x19\n\x15\x46OV_LINEAR_360HORIZON\x10\x0b\x12\x18\n\x14\x46OV_LINEAR_22HORIZON\x10\x0c\x12\x0e\n\nFOV_DEWARP\x10\r\x12\x11\n\rFOV_TYPE_MEGA\x10\x0e\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "sensor_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SENSORDEVICE"]._serialized_start = 241
    _globals["_SENSORDEVICE"]._serialized_end = 354
    _globals["_FOVTYPE"]._serialized_start = 357
    _globals["_FOVTYPE"]._serialized_end = 669
    _globals["_SENSOR"]._serialized_start = 36
    _globals["_SENSOR"]._serialized_end = 239
    _globals["_SENSOR_TYPE"]._serialized_start = 121
    _globals["_SENSOR_TYPE"]._serialized_end = 239
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_button_press_params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from button_press_params_pb2 import *
from button_press_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dset_button_press_params.proto\x12\x11insta360.messages\x1a\x19\x62utton_press_params.proto\x1a\x12\x62utton_press.proto"\x84\x02\n\x0fSetButtonParams\x12>\n\x0c\x62utton_param\x18\x01 \x03(\x0e\x32(.insta360.messages.ButtonPressParamsType\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.insta360.messages.ButtonPressParams\x12=\n\x11\x62utton_press_type\x18\x03 \x01(\x0e\x32".insta360.messages.ButtonPressType\x12=\n\x11\x62utton_press_mode\x18\x04 \x01(\x0e\x32".insta360.messages.ButtonPressMode"V\n\x13SetButtonParamsResp\x12?\n\rsuccess_types\x18\x01 \x03(\x0e\x32(.insta360.messages.ButtonPressParamsTypeB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_button_press_params_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETBUTTONPARAMS"]._serialized_start = 100
    _globals["_SETBUTTONPARAMS"]._serialized_end = 360
    _globals["_SETBUTTONPARAMSRESP"]._serialized_start = 362
    _globals["_SETBUTTONPARAMSRESP"]._serialized_end = 448
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: file_type.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x0f\x66ile_type.proto\x12\x11insta360.messages*N\n\x08\x46ileType\x12\x10\n\x0cUNKNOWN_FILE\x10\x00\x12\x0c\n\x08\x45TK_FILE\x10\x01\x12\x0c\n\x08LOG_FILE\x10\x02\x12\x14\n\x10PARAMS_JSON_FILE\x10\x03\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "file_type_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_FILETYPE"]._serialized_start = 38
    _globals["_FILETYPE"]._serialized_end = 116
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capture_trigger_source.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x1c\x63\x61pture_trigger_source.proto\x12\x11insta360.messages*\\\n\x1a\x43\x61meraCaptureTriggerSource\x12\x0f\n\x0bSOURCE_NULL\x10\x00\x12\x14\n\x10SOURCE_TIMER_REC\x10\x01\x12\x17\n\x13SOURCE_INTERVAL_REC\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "capture_trigger_source_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERACAPTURETRIGGERSOURCE"]._serialized_start = 51
    _globals["_CAMERACAPTURETRIGGERSOURCE"]._serialized_end = 143
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_photography_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from photography_options_pb2 import *
from options_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dset_photography_options.proto\x12\x11insta360.messages\x1a\x19photography_options.proto\x1a\roptions.proto"\xc5\x01\n\x15SetPhotographyOptions\x12>\n\x0coption_types\x18\x01 \x03(\x0e\x32(.insta360.messages.PhotographyOptionType\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.insta360.messages.PhotographyOptions\x12\x36\n\rfunction_mode\x18\x03 \x01(\x0e\x32\x1f.insta360.messages.FunctionMode"\\\n\x19SetPhotographyOptionsResp\x12?\n\rsuccess_types\x18\x01 \x03(\x0e\x32(.insta360.messages.PhotographyOptionTypeB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_photography_options_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETPHOTOGRAPHYOPTIONS"]._serialized_start = 95
    _globals["_SETPHOTOGRAPHYOPTIONS"]._serialized_end = 292
    _globals["_SETPHOTOGRAPHYOPTIONSRESP"]._serialized_start = 294
    _globals["_SETPHOTOGRAPHYOPTIONSRESP"]._serialized_end = 386
# @@protoc_insertion_point(module_scope)
